Learn R Programming

TaxicabCA (version 0.1.2)

SearchGeneticAlgoritm: Search a taxicab principal component using the genetic algorithm

Description

Search a taxicab principal component using the genetic algorithm

Usage

SearchGeneticAlgoritm(pResidual)

Value

A list: L1Max = maximum L1 norm; uMax = Linf unit vector giving the maximum L1 norm

Arguments

pResidual

A matrix of of non-negative numbers

Details

This function is for internal usage only.

The vector uMax is normalize to uMax[1] = 1

Examples

Run this code
SearchGeneticAlgoritm(matrix(-3:8,nrow=4,ncol=3))

Run the code above in your browser using DataLab