Learn R Programming

TaxicabCA (version 0.1.2)

plot.tca: Creates a symmetric plot from a tca-class object

Description

Creates a symmetric plot from a tca-class object

Usage

# S3 method for tca
plot(
  x,
  y = NULL,
  axes = c(1, 2),
  labels.rc = c(0, 1),
  col.rc = c("blue", "red"),
  pch.rc = c(16, 21, 17, 24),
  mass.rc = c(F, F),
  cex.rc = c(NA, NA),
  jitter = c(T, F),
  ...
)

Value

None

Arguments

x

A tca-class object created by tca

y

Unused

axes

The two axes to be plotted

labels.rc

Two numbers: 0 Symbol only; 1 Label only; 2 Symbol and label

col.rc

Colors for rows and columns contributions

pch.rc

Plotting characters for rows and columns contributions

mass.rc

Logical: Will the area of plotting characters be proportional to mass

cex.rc

An overall size factor

jitter

Logical: Will close points be moved slightly?

...

Unused.

Details

If the number of rows is very large, labels will not be printed.

In this version, jitter is coerced.

Examples

Run this code
plot(tca(rodent),labels=c(0,1))

Run the code above in your browser using DataLab