Learn R Programming

TaxicabCA (version 0.1.2)

saveTCA: Save tca results to a folder

Description

Save tca results to a folder

Usage

saveTCA(
  tcaObject,
  path,
  folder = NULL,
  what = c("report", "csv", "plot", "dataMatrix", "tcaObject"),
  plotAxes = matrix((1:2), nrow = 1, ncol = 2, byrow = T),
  graphicDevice = c("pdf", "postscript", "xfig", "bitmap", "pictex", "cairo_pdf",
    "cairo_ps", "svg", "png", "jpeg", "bmp", "tiff"),
  csvFormat = c("csv", "csv2")
)

Value

Figure

Arguments

tcaObject

a tca-class object created by tca

path

Location of the folder

folder

Name of the folder

what

What to save: all items specified will be saved

plotAxes

A k x 2 matrix giving pairs of axes to plot and save

graphicDevice

Format(s) of plots saved. Plots can be saved in more than one format

csvFormat

Format of csv files (North American or European)

Examples

Run this code
saveTCA(tca(rodent),path=tempdir())

Run the code above in your browser using DataLab